@@ -50,6 +50,7 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 #'
 #' @template ssBasicParam
 #' @template ssAdvancedParam
+#' @template ssIntervals
 #' @template ssInitialParam
 #' @template ssAuthor
 #' @template ssKeywords
@@ -207,7 +208,7 @@ ssarima <- function(y, orders=list(ar=c(0),i=c(1),ma=c(1)), lags=c(1),
                     initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC","BICc"),
                     loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                     h=10, holdout=FALSE, cumulative=FALSE,
-                    interval=c("none","parametric","semiparametric","nonparametric"), level=0.95,
+                    interval=c("none","parametric","likelihood","semiparametric","nonparametric"), level=0.95,
                     occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
                     oesmodel="MNN",
                     bounds=c("admissible","none"),
